
import Vue from 'vue'
import baseUtils from '@/utils/baseUtils'
import baseCode from '@/utils/baseCode'

Vue.mixin({
  filters: {
    money: function (price) {
      if (price) {
        let priceArr = price.toString().split('.')
        // 整数部分
        let priceArr1 = priceArr[0].split('').reverse()
        // 小数部分
        let priceArr2 = priceArr[1]
        // 处理结果
        let tmpPrice1Arr = []
        for (let i = 0; i < priceArr1.length; i++) {
          tmpPrice1Arr.push((priceArr1.length - 1 > i && (i + 1) % 3 === 0 ? ',' : '') + priceArr1[i])
        }
        tmpPrice1Arr = tmpPrice1Arr.reverse()
        if (priceArr2) {
          tmpPrice1Arr.push('.' + priceArr2)
        }
        return tmpPrice1Arr.join('')
      } else {
        return 0
      }
    },
    date: function (time) {
      if (typeof time !== 'number') {
        time = Number(time)
      }
      if (time) {
        let d = new Date(time)
        let year = d.getFullYear()
        let month = d.getMonth() + 1
        let day = d.getDate() < 10 ? '0' + d.getDate() : '' + d.getDate()
        return year + '-' + month + '-' + day
      }
    },
    // 将 yyyy-MM-dd hh:mm:ss 转成 hh:mm:ss
    dateStr: function (dateStr) {
      return dateStr ? dateStr.substring(0, 10) : '—'
    }
  },
  computed: {
    baseUtils () {
      return baseUtils
    },
    baseCode () {
      return baseCode
    },
    user () {
      return this.$store.state.auth.user
    }
  },
  methods: {
    goRouter (url) {
      if (url) {
        this.$router.push(url)
      }
    },
    loginInterceptor (callback) {
      if (!this.$store.state.auth.user.logged) {
        window.location.href = this.$store.getters['options/loginUrl'] + `&returnURL=${window.location.href}`
      } else {
        callback.call()
      }
    },
    getRequestDeal (res, call) {
      if (res.data.respHeader && res.data.respHeader.code === 0) {
        call(res.data)
      } else {
        this.$message.show(res.data.respHeader.msg)
      }
    }
  }
})
