import Vue from 'vue'
import Router from 'vue-router'
import store from '../store'
import { Home } from '@/components/home'
import { FactoringEntry } from '@/components/factoring'
import { CenterEntry, CenterHome, CenterLimit, LimitApplyRecord, Withdraw, WithdrawApplyRecord, Message, Repayment, LimitApply, AddLimit } from '@/components/center'
import { PlanDetail, WithdrawDetail } from '@/components/detail'
import { ResultEntry } from '@/components/result'
// import { AuthLogin } from '@/components/auth'

Vue.use(Router)

const route = new Router({
  routes: [
    // 登录代理页
    // {
    //   path: '/authLogin',
    //   name: 'authLogin',
    //   component: AuthLogin
    // },
    // 首页
    {
      path: '/',
      name: 'home',
      component: Home,
      meta: {
        title: 'U智融'
      }
    },
    // 首页-保理
    {
      path: '/factoring',
      name: 'factoring',
      component: FactoringEntry,
      meta: {
        title: 'U智融-保理'
      }
    },
    // 客户中心
    {
      path: '/center',
      name: 'center',
      component: CenterEntry,
      children: [
        {
          // 客户中心首页
          path: 'home',
          name: 'centerHome',
          component: CenterHome,
          meta: {
            requiresAuth: true,
            title: 'U智融-客户中心'
          }
        },
        {
          // 我的额度
          path: 'limit',
          name: 'centerLimit',
          component: CenterLimit,
          meta: {
            requiresAuth: true,
            title: 'U智融-我的额度'
          }
        },
        {
          // 额度申请记录
          path: 'limitApplyRecord',
          name: 'limitApplyRecord',
          component: LimitApplyRecord,
          meta: {
            requiresAuth: true,
            title: 'U智融-额度申请记录'
          }
        },
        {
          // 我要提款
          path: 'withdraw/:code',
          name: 'withdraw',
          component: Withdraw,
          meta: {
            requiresAuth: true,
            title: 'U智融-我要提款'
          }
        },
        {
          // 提款申请记录
          path: 'withdrawApplyRecord',
          name: 'withdrawApplyRecord',
          component: WithdrawApplyRecord,
          meta: {
            requiresAuth: true,
            title: 'U智融-提款申请记录'
          }
        },
        {
          // 我的还款
          path: 'repayment',
          name: 'repayment',
          component: Repayment,
          meta: {
            requiresAuth: true,
            title: 'U智融-我的还款'
          }
        },
        {
          // 消息中心
          path: 'message',
          name: 'message',
          component: Message,
          meta: {
            requiresAuth: true,
            title: 'U智融-消息中心'
          }
        },
        {
          // 额度申请
          path: 'limitApply',
          name: 'limitApply',
          component: LimitApply,
          meta: {
            requiresAuth: true,
            title: 'U智融-额度申请'
          }
        },
        {
          // 增额申请
          path: 'addLimit/:code',
          name: 'addLimit',
          component: AddLimit,
          meta: {
            requiresAuth: true,
            title: 'U智融-增额申请'
          }
        }
      ]
    },
    {
      /*
       * @type:plan => 提款申请记录-还款计划
       *      :detail => 我的还款-还款明细
       * */
      path: '/planDetail/:type/:code',
      name: 'planDetail',
      component: PlanDetail,
      meta: {
        requiresAuth: true,
        title: 'U智融-还款明细'
      }
    },
    // 提款详情
    {
      path: '/withdrawDetail/:id',
      name: 'withdrawDetail',
      component: WithdrawDetail,
      meta: {
        requiresAuth: true,
        title: 'U智融-提款详情'
      }
    },
    /*
     * 结果页
     * @type:limit => 额度申请
     *      :addLimit => 增额申请
     *      :withdraw => 提款申请
     * */
    {
      path: '/result/:type',
      name: 'result',
      component: ResultEntry,
      meta: {
        requiresAuth: true,
        title: 'U智融-申请结果'
      }
    }
  ],
  mode: 'history'
})

// 登录判断
let authInterceptor = (to, next) => {
  let logged = store.state.auth.user.logged
  if (to.meta.requiresAuth && !logged) {
    window.location.href = store.getters['options/loginUrl'] + `&returnURL=${window.location.href}`
    // next({
    //   path: '/authLogin',
    //   query: {
    //     'returnURL': window.location.href
    //   }
    // })
  } else {
    next()
  }
}

 route.beforeEach((to, from, next) => {
  // 登陆守卫
   if (to.meta.title) {
     if (to.name === 'planDetail') {
       if (to.params.type === 'plan') {
         document.title = 'U智融-还款计划'
       } else {
         document.title = 'U智融-还款明细'
       }
     } else {
       document.title = to.meta.title
     }
   }
   if (!store.state.auth.user.getAuthed) {
     // 获取登录信息
     store.dispatch('auth/getAuth').then(() => {
       authInterceptor(to, next)
     }, () => {
       authInterceptor(to, next)
     })
   } else {
     authInterceptor(to, next)
   }
})
export default route
