const state = {
  // 控制全局loading
  showLoading: false,
  isProd: process.env.NODE_ENV === 'production',
  // 消息提示
  remindBox: {
    show: false,
    text: '',
    type: 'success'
  },
  // 树组件传递的内容
  treeAction: {}
}

// getters
const getters = {
  // 账户中心地址
  ssoUrl: (state, getters, rootState) => {
    return state.isProd ? 'https://sso.ubtob.com' : 'https://sso.ubtob.com'
  },
  // 登录地址
  loginUrl: (state, getters, rootState) => {
    return `${getters.ssoUrl}/?appId=fin&baseUrl=${state.isProd ? 'https://ssorest.uuzcc.cn/web/api/login' : 'https://ssorest.usoftchina.com/web/api/login'}`
  },
  // 退出地址
  logoutUrl: (state, getters, rootState) => {
    return `${getters.ssoUrl}/logquit?baseUrl=${state.isProd ? 'https://ssorest.uuzcc.cn/web/api/logout' : 'https://ssorest.usoftchina.com/web/api/logout'}`
  },
  // 注册地址
  registerUrl: (state, getters, rootState) => {
    return `${getters.ssoUrl}/register/enterpriseRegistration?appId=fin`
  },
  // 账户云中心地址
  ssoCenterUrl: (state, getters, rootState) => {
    return `${getters.ssoUrl}/cloudCenter`
  }
}

// actions
const actions = {
  // 设置loading状态
  setShowLoading ({ commit }, isShow) {
    commit('SET_SHOW_LOADING', isShow)
  },
  // 设置提示框状态
  setShowRemindBox ({ commit }, remindObj) {
    commit('SET_REMIND_BOX', remindObj)
  },
  // 树组件action
  setTreeAction ({ commit }, data) {
    commit('SET_TREE_ACTION', data)
  }
}

// mutations
const mutations = {
  SET_SHOW_LOADING (state, isShow) {
    state.showLoading = isShow
  },
  SET_REMIND_BOX (state, remindObj) {
    state.remindBox = remindObj
  },
  SET_TREE_ACTION (state, data) {
    state.treeAction = data
  }
}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations
}
